# Generated by Django 5.1.5 on 2025-01-26 19:50

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CoreHealthcheck',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, unique=True)),
                ('healthcheck_run_datetime', models.DateTimeField(blank=True, null=True, verbose_name='Healthcheck Run Datetime')),
            ],
            options={
                'verbose_name': 'Core Healthcheck',
                'verbose_name_plural': 'Core Healthchecks',
            },
        ),
    ]
